{% extends "base.html" %}

{% block title %}Welcome to {{ program_name }}{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <div class="form-group">
    <div class="card impact-card">
        <div class="card-header impact-card-header">
            <h4>Get Started</h4>
        </div>
        <div class="card-body">
            <div class="form-group">
                {% if new_account %}
                    <p>An account for {{ school_name }} has been set up and will expire in {{ trial_length }} days.</p>
                    <p>Invite other staff to join the school account by sharing the school code: {{ school_code }}</p>
                {% else %}
                    <p>Your account has been linked to {{ school_name }}.</p>
                {% endif %}

            </div>
        </div>
    </div>
    </div>

    <div class="form-group">
        <a href="{% url 'home' %}" class="btn btn-success" role="button">Start <i class="material-icons">chevron_right</i></a>
    </div>
    </div>

    </main>
{% endblock %}
