{% extends "default-base.html" %}

    {% block title %}{{ program_name }} - About{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <div class="form-group">
    <div class="card generic-card-card">
        <div class="card-header generic-card-header">
            <h4>About {{ program_name }}</h4>
        </div>
        <div class="card-body">
            <div class="form-group">
                <h4>Release information</h4>
                <p>Impact version: {{ program_version }}</p>
                <p>Release date: {{ program_release_date }}</p>
            </div>

            <div class="form-group">
            <h4>Copyright information</h4>
            <p><a href="https://education.gov.scot/improvement/documents/frameworks_selfevaluation/frwk2_nihedithgios/frwk2_hgios4.pdf">
                How good is our school? (4th edition)</a>
                is copyright Education Scotland.
            <p>
            <p><a href="https://education.gov.scot/improvement/Documents/HGIOURS-Part1.pdf">
                How good is OUR school? (1st edition) Part One</a>
                and
                <a href="https://education.gov.scot/improvement/Documents/HGIOURS-Part2.pdf">
                How good is OUR school? (1st edition) Part Two</a>
                are copyright Education Scotland.
            <p>
            <p>Both documents are licenced under the
               <a href="http://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/">Open Government Licence</a>.
            </p>
            </div>
        </div>
    </div>
    </div>


    <div class="form-group">
    <a href="{% url 'core_nav:settings' %}" class="btn btn-primary" role="button">Done</a>
    </div>

    </div>



    </main>

{% endblock %}